@@ -8,9 +8,9 @@ use Scalar::Util qw(refaddr blessed weaken);
 use Carp;
 use Try::Tiny ();
 
-our $VERSION = '0.110';
+our $VERSION = '0.120';
 
-our @CARP_NOT = qw(Try::Tiny Future);
+our @CARP_NOT = qw(Try::Tiny Future Future::PP Future::XS);
 
 our $OnError = undef;
 
